orcid\_hub package
==================

Submodules
----------

orcid\_hub\.api module
----------------------

.. automodule:: orcid_hub.api
    :members:
    :undoc-members:
    :show-inheritance:

orcid\_hub\.authcontroller module
---------------------------------

.. automodule:: orcid_hub.authcontroller
    :members:
    :undoc-members:
    :show-inheritance:

orcid\_hub\.cli module
----------------------

.. automodule:: orcid_hub.cli
    :members:
    :undoc-members:
    :show-inheritance:

orcid\_hub\.config module
-------------------------

.. automodule:: orcid_hub.config
    :members:
    :undoc-members:
    :show-inheritance:

orcid\_hub\.failover module
---------------------------

.. automodule:: orcid_hub.failover
    :members:
    :undoc-members:
    :show-inheritance:

orcid\_hub\.forms module
------------------------

.. automodule:: orcid_hub.forms
    :members:
    :undoc-members:
    :show-inheritance:

orcid\_hub\.login\_provider module
----------------------------------

.. automodule:: orcid_hub.login_provider
    :members:
    :undoc-members:
    :show-inheritance:

orcid\_hub\.models module
-------------------------

.. automodule:: orcid_hub.models
    :members:
    :undoc-members:
    :show-inheritance:

orcid\_hub\.oauth module
------------------------

.. automodule:: orcid_hub.oauth
    :members:
    :undoc-members:
    :show-inheritance:

orcid\_hub\.orcid\_client module
--------------------------------

.. automodule:: orcid_hub.orcid_client
    :members:
    :undoc-members:
    :show-inheritance:

orcid\_hub\.pyinfo module
-------------------------

.. automodule:: orcid_hub.pyinfo
    :members:
    :undoc-members:
    :show-inheritance:

orcid\_hub\.reports module
--------------------------

.. automodule:: orcid_hub.reports
    :members:
    :undoc-members:
    :show-inheritance:


orcid\_hub\.utils module
------------------------

.. automodule:: orcid_hub.utils
    :members:
    :undoc-members:
    :show-inheritance:

orcid\_hub\.views module
------------------------

.. automodule:: orcid_hub.views
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: orcid_hub
    :members:
    :undoc-members:
    :show-inheritance:
